# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: servicebridge.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'servicebridge.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13servicebridge.proto\x12\rservicebridge\"O\n\rHandleRequest\x12\n\n\x02\x66n\x18\x01 \x01(\t\x12\x0f\n\x07payload\x18\x02 \x01(\x0c\x12\x10\n\x08trace_id\x18\x03 \x01(\t\x12\x0f\n\x07span_id\x18\x04 \x01(\t\"@\n\x0eHandleResponse\x12\x0e\n\x06output\x18\x01 \x01(\x0c\x12\x0f\n\x07success\x18\x02 \x01(\x08\x12\r\n\x05\x65rror\x18\x03 \x01(\t\"\x8e\x02\n\x15\x44\x65liverMessageRequest\x12\x12\n\nmessage_id\x18\x01 \x01(\t\x12\x12\n\ngroup_name\x18\x02 \x01(\t\x12\r\n\x05topic\x18\x03 \x01(\t\x12\x0f\n\x07payload\x18\x04 \x01(\x0c\x12\x42\n\x07headers\x18\x05 \x03(\x0b\x32\x31.servicebridge.DeliverMessageRequest.HeadersEntry\x12\x10\n\x08trace_id\x18\x06 \x01(\t\x12\x16\n\x0eparent_span_id\x18\x07 \x01(\t\x12\x0f\n\x07\x61ttempt\x18\x08 \x01(\x05\x1a.\n\x0cHeadersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xfa\x01\n\x0ePublishRequest\x12\r\n\x05topic\x18\x01 \x01(\t\x12\x0f\n\x07payload\x18\x02 \x01(\x0c\x12;\n\x07headers\x18\x03 \x03(\x0b\x32*.servicebridge.PublishRequest.HeadersEntry\x12\x10\n\x08trace_id\x18\x04 \x01(\t\x12\x16\n\x0eparent_span_id\x18\x05 \x01(\t\x12\x18\n\x10producer_service\x18\x06 \x01(\t\x12\x17\n\x0fidempotency_key\x18\x07 \x01(\t\x1a.\n\x0cHeadersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"%\n\x0fPublishResponse\x12\x12\n\nmessage_id\x18\x01 \x01(\t\"X\n\x0b\x44\x65liveryAck\x12\x0b\n\x03\x61\x63k\x18\x01 \x01(\x08\x12\x16\n\x0eretry_after_ms\x18\x02 \x01(\x05\x12\x15\n\rreject_reason\x18\x03 \x01(\t\x12\r\n\x05\x65rror\x18\x04 \x01(\t\".\n\x14WatchRegistryRequest\x12\x16\n\x0e\x66unction_names\x18\x01 \x03(\t\"(\n\x15LookupFunctionRequest\x12\x0f\n\x07\x66n_name\x18\x01 \x01(\t\"o\n\x16LookupFunctionResponse\x12\r\n\x05\x66ound\x18\x01 \x01(\x08\x12\x16\n\x0e\x63\x61nonical_name\x18\x02 \x01(\t\x12.\n\tendpoints\x18\x03 \x01(\x0b\x32\x1b.servicebridge.EndpointList\"\xb1\x01\n\x0fRegistryMessage\x12\x30\n\x04kind\x18\x01 \x01(\x0e\x32\".servicebridge.RegistryMessageKind\x12\x10\n\x08revision\x18\x02 \x01(\x03\x12-\n\x04\x66ull\x18\x03 \x01(\x0b\x32\x1f.servicebridge.RegistrySnapshot\x12+\n\x05\x64\x65lta\x18\x04 \x01(\x0b\x32\x1c.servicebridge.RegistryDelta\"\xaa\x01\n\rRegistryDelta\x12:\n\x07upserts\x18\x01 \x03(\x0b\x32).servicebridge.RegistryDelta.UpsertsEntry\x12\x10\n\x08removals\x18\x02 \x03(\t\x1aK\n\x0cUpsertsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12*\n\x05value\x18\x02 \x01(\x0b\x32\x1b.servicebridge.EndpointList:\x02\x38\x01\"Z\n\x0eWorkerEndpoint\x12\x10\n\x08\x65ndpoint\x18\x01 \x01(\t\x12\x11\n\ttransport\x18\x02 \x01(\t\x12\x13\n\x0binstance_id\x18\x03 \x01(\t\x12\x0e\n\x06weight\x18\x04 \x01(\x05\"\x92\x01\n\x10RegistrySnapshot\x12\x35\n\x03rpc\x18\x01 \x03(\x0b\x32(.servicebridge.RegistrySnapshot.RpcEntry\x1aG\n\x08RpcEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12*\n\x05value\x18\x02 \x01(\x0b\x32\x1b.servicebridge.EndpointList:\x02\x38\x01\"\x96\x01\n\x0c\x45ndpointList\x12\x30\n\tendpoints\x18\x01 \x03(\x0b\x32\x1d.servicebridge.WorkerEndpoint\x12\x19\n\x11input_schema_json\x18\x02 \x01(\t\x12\x1a\n\x12output_schema_json\x18\x03 \x01(\t\x12\x17\n\x0f\x61llowed_callers\x18\x04 \x03(\tJ\x04\x08\x05\x10\x08\"\xbe\x01\n\x16ReportCallStartRequest\x12\x10\n\x08trace_id\x18\x01 \x01(\t\x12\x0f\n\x07span_id\x18\x02 \x01(\t\x12\n\n\x02\x66n\x18\x03 \x01(\t\x12\x14\n\x0cservice_name\x18\x04 \x01(\t\x12\x12\n\nstarted_at\x18\x05 \x01(\x03\x12\r\n\x05input\x18\x06 \x01(\x0c\x12\x0f\n\x07\x61ttempt\x18\x07 \x01(\x05\x12\x16\n\x0eparent_span_id\x18\x08 \x01(\t\x12\x13\n\x0binstance_id\x18\t \x01(\t\"\xe6\x01\n\x11ReportCallRequest\x12\x10\n\x08trace_id\x18\x01 \x01(\t\x12\x0f\n\x07span_id\x18\x02 \x01(\t\x12\n\n\x02\x66n\x18\x03 \x01(\t\x12\x14\n\x0cservice_name\x18\x04 \x01(\t\x12\x12\n\nstarted_at\x18\x05 \x01(\x03\x12\x13\n\x0b\x64uration_ms\x18\x06 \x01(\x03\x12\x0f\n\x07success\x18\x07 \x01(\x08\x12\r\n\x05\x65rror\x18\x08 \x01(\t\x12\r\n\x05input\x18\t \x01(\x0c\x12\x0e\n\x06output\x18\n \x01(\x0c\x12\x0f\n\x07\x61ttempt\x18\x0b \x01(\x05\x12\x13\n\x0binstance_id\x18\x0c \x01(\t\"\x14\n\x12ReportCallResponse\"\xfe\x01\n\x08LogEntry\x12\x10\n\x08trace_id\x18\x01 \x01(\t\x12\x0f\n\x07span_id\x18\x02 \x01(\t\x12\x14\n\x0cservice_name\x18\x03 \x01(\t\x12\r\n\x05level\x18\x04 \x01(\t\x12\x0f\n\x07message\x18\x05 \x01(\t\x12\x14\n\x0ctimestamp_ns\x18\x06 \x01(\x03\x12;\n\nattributes\x18\x07 \x03(\x0b\x32\'.servicebridge.LogEntry.AttributesEntry\x12\x13\n\x0binstance_id\x18\x08 \x01(\t\x1a\x31\n\x0f\x41ttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"<\n\x10ReportLogRequest\x12(\n\x07\x65ntries\x18\x01 \x03(\x0b\x32\x17.servicebridge.LogEntry\"\x13\n\x11ReportLogResponse\"\xc1\x01\n\x17RegisterFunctionRequest\x12\x0f\n\x07\x66n_name\x18\x01 \x01(\t\x12\x14\n\x0cservice_name\x18\x02 \x01(\t\x12\x13\n\x0binstance_id\x18\x03 \x01(\t\x12\x10\n\x08\x65ndpoint\x18\x04 \x01(\t\x12\x0e\n\x06weight\x18\x05 \x01(\x05\x12\x19\n\x11input_schema_json\x18\x06 \x01(\t\x12\x1a\n\x12output_schema_json\x18\x07 \x01(\t\x12\x11\n\ttransport\x18\x08 \x01(\t\"\x1a\n\x18RegisterFunctionResponse\"\x91\x01\n\x1cRegisterConsumerGroupRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07pattern\x18\x02 \x01(\t\x12\x0c\n\x04mode\x18\x03 \x01(\t\x12\x19\n\x11retry_policy_json\x18\x04 \x01(\t\x12\x0e\n\x06\x61\x63tive\x18\x06 \x01(\x08\x12\x13\n\x0b\x66ilter_expr\x18\x07 \x01(\tJ\x04\x08\x05\x10\x06\"\x1f\n\x1dRegisterConsumerGroupResponse\"\x90\x01\n\x1aRegisterGroupMemberRequest\x12\x12\n\ngroup_name\x18\x01 \x01(\t\x12\x14\n\x0cservice_name\x18\x02 \x01(\t\x12\x13\n\x0binstance_id\x18\x03 \x01(\t\x12\x10\n\x08\x65ndpoint\x18\x04 \x01(\t\x12\x0e\n\x06weight\x18\x05 \x01(\x05\x12\x11\n\ttransport\x18\x06 \x01(\t\"\x1d\n\x1bRegisterGroupMemberResponse\"\xd9\x01\n\x10HeartbeatRequest\x12\x14\n\x0cservice_name\x18\x01 \x01(\t\x12\x13\n\x0binstance_id\x18\x02 \x01(\t\x12\x10\n\x08\x65ndpoint\x18\x03 \x01(\t\x12\x13\n\x0bgroup_names\x18\x04 \x03(\t\x12\x16\n\x0e\x66unction_names\x18\x05 \x03(\t\x12\x11\n\ttransport\x18\x06 \x01(\t\x12\x18\n\x0b\x63pu_percent\x18\x07 \x01(\x02H\x00\x88\x01\x01\x12\x13\n\x06ram_mb\x18\x08 \x01(\x05H\x01\x88\x01\x01\x42\x0e\n\x0c_cpu_percentB\t\n\x07_ram_mb\"\x13\n\x11HeartbeatResponse\"_\n\x17RegisterWorkflowRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\ndefinition\x18\x02 \x01(\t\x12\x0c\n\x04opts\x18\x03 \x01(\t\x12\x14\n\x0cservice_name\x18\x04 \x01(\t\"&\n\x18RegisterWorkflowResponse\x12\n\n\x02id\x18\x01 \x01(\t\"\xbd\x01\n\x12RegisterJobRequest\x12\x11\n\tcron_expr\x18\x01 \x01(\t\x12\x10\n\x08timezone\x18\x02 \x01(\t\x12\x16\n\x0emisfire_policy\x18\x03 \x01(\t\x12\x13\n\x0btarget_type\x18\x04 \x01(\t\x12\x12\n\ntarget_ref\x18\x05 \x01(\t\x12\x10\n\x08\x64\x65lay_ms\x18\x06 \x01(\x05\x12\x14\n\x0cservice_name\x18\x07 \x01(\t\x12\x19\n\x11retry_policy_json\x18\x08 \x01(\t\"!\n\x13RegisterJobResponse\x12\n\n\x02id\x18\x01 \x01(\t\"@\n\x13\x41ppendStreamRequest\x12\x0e\n\x06run_id\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\x0c\"\x16\n\x14\x41ppendStreamResponse\"E\n\x0fWatchRunRequest\x12\x0e\n\x06run_id\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\x15\n\rfrom_sequence\x18\x03 \x01(\x03\"e\n\x0eRunStreamChunk\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x03 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x04 \x01(\x0c\x12\x10\n\x08sequence\x18\x05 \x01(\x03\x12\x12\n\nrun_status\x18\x06 \x01(\tJ\x04\x08\x02\x10\x03**\n\x13RegistryMessageKind\x12\x08\n\x04\x46ULL\x10\x00\x12\t\n\x05\x44\x45LTA\x10\x01\x32\x88\n\n\rServiceBridge\x12\x63\n\x10RegisterFunction\x12&.servicebridge.RegisterFunctionRequest\x1a\'.servicebridge.RegisterFunctionResponse\x12r\n\x15RegisterConsumerGroup\x12+.servicebridge.RegisterConsumerGroupRequest\x1a,.servicebridge.RegisterConsumerGroupResponse\x12l\n\x13RegisterGroupMember\x12).servicebridge.RegisterGroupMemberRequest\x1a*.servicebridge.RegisterGroupMemberResponse\x12N\n\tHeartbeat\x12\x1f.servicebridge.HeartbeatRequest\x1a .servicebridge.HeartbeatResponse\x12\x63\n\x10RegisterWorkflow\x12&.servicebridge.RegisterWorkflowRequest\x1a\'.servicebridge.RegisterWorkflowResponse\x12T\n\x0bRegisterJob\x12!.servicebridge.RegisterJobRequest\x1a\".servicebridge.RegisterJobResponse\x12V\n\rWatchRegistry\x12#.servicebridge.WatchRegistryRequest\x1a\x1e.servicebridge.RegistryMessage0\x01\x12]\n\x0eLookupFunction\x12$.servicebridge.LookupFunctionRequest\x1a%.servicebridge.LookupFunctionResponse\x12[\n\x0fReportCallStart\x12%.servicebridge.ReportCallStartRequest\x1a!.servicebridge.ReportCallResponse\x12Q\n\nReportCall\x12 .servicebridge.ReportCallRequest\x1a!.servicebridge.ReportCallResponse\x12N\n\tReportLog\x12\x1f.servicebridge.ReportLogRequest\x1a .servicebridge.ReportLogResponse\x12H\n\x07Publish\x12\x1d.servicebridge.PublishRequest\x1a\x1e.servicebridge.PublishResponse\x12W\n\x0c\x41ppendStream\x12\".servicebridge.AppendStreamRequest\x1a#.servicebridge.AppendStreamResponse\x12K\n\x08WatchRun\x12\x1e.servicebridge.WatchRunRequest\x1a\x1d.servicebridge.RunStreamChunk0\x01\x32\xb0\x01\n\x13ServiceBridgeWorker\x12\x45\n\x06Handle\x12\x1c.servicebridge.HandleRequest\x1a\x1d.servicebridge.HandleResponse\x12R\n\x0e\x44\x65liverMessage\x12$.servicebridge.DeliverMessageRequest\x1a\x1a.servicebridge.DeliveryAckB3Z1github.com/servicebridge/server-go/internal/pb;pbb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'servicebridge_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z1github.com/servicebridge/server-go/internal/pb;pb'
  _globals['_DELIVERMESSAGEREQUEST_HEADERSENTRY']._loaded_options = None
  _globals['_DELIVERMESSAGEREQUEST_HEADERSENTRY']._serialized_options = b'8\001'
  _globals['_PUBLISHREQUEST_HEADERSENTRY']._loaded_options = None
  _globals['_PUBLISHREQUEST_HEADERSENTRY']._serialized_options = b'8\001'
  _globals['_REGISTRYDELTA_UPSERTSENTRY']._loaded_options = None
  _globals['_REGISTRYDELTA_UPSERTSENTRY']._serialized_options = b'8\001'
  _globals['_REGISTRYSNAPSHOT_RPCENTRY']._loaded_options = None
  _globals['_REGISTRYSNAPSHOT_RPCENTRY']._serialized_options = b'8\001'
  _globals['_LOGENTRY_ATTRIBUTESENTRY']._loaded_options = None
  _globals['_LOGENTRY_ATTRIBUTESENTRY']._serialized_options = b'8\001'
  _globals['_REGISTRYMESSAGEKIND']._serialized_start=4030
  _globals['_REGISTRYMESSAGEKIND']._serialized_end=4072
  _globals['_HANDLEREQUEST']._serialized_start=38
  _globals['_HANDLEREQUEST']._serialized_end=117
  _globals['_HANDLERESPONSE']._serialized_start=119
  _globals['_HANDLERESPONSE']._serialized_end=183
  _globals['_DELIVERMESSAGEREQUEST']._serialized_start=186
  _globals['_DELIVERMESSAGEREQUEST']._serialized_end=456
  _globals['_DELIVERMESSAGEREQUEST_HEADERSENTRY']._serialized_start=410
  _globals['_DELIVERMESSAGEREQUEST_HEADERSENTRY']._serialized_end=456
  _globals['_PUBLISHREQUEST']._serialized_start=459
  _globals['_PUBLISHREQUEST']._serialized_end=709
  _globals['_PUBLISHREQUEST_HEADERSENTRY']._serialized_start=410
  _globals['_PUBLISHREQUEST_HEADERSENTRY']._serialized_end=456
  _globals['_PUBLISHRESPONSE']._serialized_start=711
  _globals['_PUBLISHRESPONSE']._serialized_end=748
  _globals['_DELIVERYACK']._serialized_start=750
  _globals['_DELIVERYACK']._serialized_end=838
  _globals['_WATCHREGISTRYREQUEST']._serialized_start=840
  _globals['_WATCHREGISTRYREQUEST']._serialized_end=886
  _globals['_LOOKUPFUNCTIONREQUEST']._serialized_start=888
  _globals['_LOOKUPFUNCTIONREQUEST']._serialized_end=928
  _globals['_LOOKUPFUNCTIONRESPONSE']._serialized_start=930
  _globals['_LOOKUPFUNCTIONRESPONSE']._serialized_end=1041
  _globals['_REGISTRYMESSAGE']._serialized_start=1044
  _globals['_REGISTRYMESSAGE']._serialized_end=1221
  _globals['_REGISTRYDELTA']._serialized_start=1224
  _globals['_REGISTRYDELTA']._serialized_end=1394
  _globals['_REGISTRYDELTA_UPSERTSENTRY']._serialized_start=1319
  _globals['_REGISTRYDELTA_UPSERTSENTRY']._serialized_end=1394
  _globals['_WORKERENDPOINT']._serialized_start=1396
  _globals['_WORKERENDPOINT']._serialized_end=1486
  _globals['_REGISTRYSNAPSHOT']._serialized_start=1489
  _globals['_REGISTRYSNAPSHOT']._serialized_end=1635
  _globals['_REGISTRYSNAPSHOT_RPCENTRY']._serialized_start=1564
  _globals['_REGISTRYSNAPSHOT_RPCENTRY']._serialized_end=1635
  _globals['_ENDPOINTLIST']._serialized_start=1638
  _globals['_ENDPOINTLIST']._serialized_end=1788
  _globals['_REPORTCALLSTARTREQUEST']._serialized_start=1791
  _globals['_REPORTCALLSTARTREQUEST']._serialized_end=1981
  _globals['_REPORTCALLREQUEST']._serialized_start=1984
  _globals['_REPORTCALLREQUEST']._serialized_end=2214
  _globals['_REPORTCALLRESPONSE']._serialized_start=2216
  _globals['_REPORTCALLRESPONSE']._serialized_end=2236
  _globals['_LOGENTRY']._serialized_start=2239
  _globals['_LOGENTRY']._serialized_end=2493
  _globals['_LOGENTRY_ATTRIBUTESENTRY']._serialized_start=2444
  _globals['_LOGENTRY_ATTRIBUTESENTRY']._serialized_end=2493
  _globals['_REPORTLOGREQUEST']._serialized_start=2495
  _globals['_REPORTLOGREQUEST']._serialized_end=2555
  _globals['_REPORTLOGRESPONSE']._serialized_start=2557
  _globals['_REPORTLOGRESPONSE']._serialized_end=2576
  _globals['_REGISTERFUNCTIONREQUEST']._serialized_start=2579
  _globals['_REGISTERFUNCTIONREQUEST']._serialized_end=2772
  _globals['_REGISTERFUNCTIONRESPONSE']._serialized_start=2774
  _globals['_REGISTERFUNCTIONRESPONSE']._serialized_end=2800
  _globals['_REGISTERCONSUMERGROUPREQUEST']._serialized_start=2803
  _globals['_REGISTERCONSUMERGROUPREQUEST']._serialized_end=2948
  _globals['_REGISTERCONSUMERGROUPRESPONSE']._serialized_start=2950
  _globals['_REGISTERCONSUMERGROUPRESPONSE']._serialized_end=2981
  _globals['_REGISTERGROUPMEMBERREQUEST']._serialized_start=2984
  _globals['_REGISTERGROUPMEMBERREQUEST']._serialized_end=3128
  _globals['_REGISTERGROUPMEMBERRESPONSE']._serialized_start=3130
  _globals['_REGISTERGROUPMEMBERRESPONSE']._serialized_end=3159
  _globals['_HEARTBEATREQUEST']._serialized_start=3162
  _globals['_HEARTBEATREQUEST']._serialized_end=3379
  _globals['_HEARTBEATRESPONSE']._serialized_start=3381
  _globals['_HEARTBEATRESPONSE']._serialized_end=3400
  _globals['_REGISTERWORKFLOWREQUEST']._serialized_start=3402
  _globals['_REGISTERWORKFLOWREQUEST']._serialized_end=3497
  _globals['_REGISTERWORKFLOWRESPONSE']._serialized_start=3499
  _globals['_REGISTERWORKFLOWRESPONSE']._serialized_end=3537
  _globals['_REGISTERJOBREQUEST']._serialized_start=3540
  _globals['_REGISTERJOBREQUEST']._serialized_end=3729
  _globals['_REGISTERJOBRESPONSE']._serialized_start=3731
  _globals['_REGISTERJOBRESPONSE']._serialized_end=3764
  _globals['_APPENDSTREAMREQUEST']._serialized_start=3766
  _globals['_APPENDSTREAMREQUEST']._serialized_end=3830
  _globals['_APPENDSTREAMRESPONSE']._serialized_start=3832
  _globals['_APPENDSTREAMRESPONSE']._serialized_end=3854
  _globals['_WATCHRUNREQUEST']._serialized_start=3856
  _globals['_WATCHRUNREQUEST']._serialized_end=3925
  _globals['_RUNSTREAMCHUNK']._serialized_start=3927
  _globals['_RUNSTREAMCHUNK']._serialized_end=4028
  _globals['_SERVICEBRIDGE']._serialized_start=4075
  _globals['_SERVICEBRIDGE']._serialized_end=5363
  _globals['_SERVICEBRIDGEWORKER']._serialized_start=5366
  _globals['_SERVICEBRIDGEWORKER']._serialized_end=5542
# @@protoc_insertion_point(module_scope)
